@@ -1,4 +1,4 @@
-__all__ = ['titanic_survive', 'titanic_fare', 'titanic_names']
+__all__ = ['titanic_survive', 'titanic_fare', 'titanic_class', 'titanic_names']
 
 import pandas as pd
 from pathlib import Path
@@ -21,5 +21,13 @@ def titanic_fare():
     y_test = d_test['Fare']
     return X_train, y_train, X_test, y_test
 
+def titanic_class():
+    X_train = d_train.drop(['PassengerClass', 'Name'], axis=1)
+    y_train = d_train['PassengerClass'] - 1
+    X_test = d_test.drop(['PassengerClass', 'Name'], axis=1)
+    y_test = d_test['PassengerClass'] - 1
+    return X_train, y_train, X_test, y_test
+
+
 def titanic_names():
     return (d_train['Name'].values.tolist(), d_test['Name'].values.tolist())
